unit AccessIniFile;

interface

uses
  Classes,
  SysUtils,
  IniFiles,
  StringUnit,
//  XPtest,
uses_end;

type
  TIniAccess = (iaRead, iaWrite, iaDeleteKey, iaEraseSection, iaReadSection);

type
  TAccessIniFile = class(TCustomIniFile)
  private
    FFileName: string;
    FOriginalIniFileText: string;
    FSections: TStringList;
    function AccessString(const Section: string; const Ident: string;
     const Value: string; Strings: TStrings; Access: TIniAccess): string;
  public
    constructor Create(const FileName: string);
    destructor Destroy; override;
    function ReadString(const Section, Ident, Default: string): string; override;
    procedure WriteString(const Section, Ident, Value: String); override;
    procedure ReadSection(const Section: string; Strings: TStrings); override;
    procedure ReadSections(Strings: TStrings); override;
    procedure ReadSectionValues(const Section: string; Strings: TStrings); override;
    procedure EraseSection(const Section: string); override;
    procedure DeleteKey(const Section, Ident: String); override;
    procedure UpdateFile; override;
  end;

implementation

{ TAccessIniFile }

constructor TAccessIniFile.Create(const FileName: string);
begin
  FFileName := FileName;
  FSections := TStringList.Create;
  if (Filename <> '') and (FileExists(FFileName)) then
  begin
    FSections.LoadFromFile(FFileName);
  end;
  FOriginalIniFileText := FSections.Text;
end;

destructor TAccessIniFile.Destroy;
begin
  UpdateFile;

  FSections.Free;
  inherited;
end;

procedure TAccessIniFile.UpdateFile;
begin
  if FOriginalIniFileText <> FSections.Text then
  begin
    FSections.SaveToFile(FFileName);
  end;
end;

{-------------------------------
//  召֌WȂłAnsiPos
@\:
l:
:       2006/07/08(y) 10:52
//--------------------------}
function AnsiPosText(const Substr, S: string): Integer;
begin
  Result :=
    AnsiPos(AnsiUpperCase(Substr), AnsiUpperCase(S));
end;
//--------------------------

{-------------------------------
//  GetName
//    擪́w=x荶̕擾
//  GetValue
//    擪́w=xE̕擾
@\:       ߂lɁw=x͊܂܂ȂB
            ֐Ȃ̂ŌĂяo
            LineStrɂ͉s͊܂܂ȂƂ݂ȂĂ
l:
:       2006/07/08(y) 10:52
//--------------------------}
function GetName(const LineStr: string): string;
var
  EqualPosition: Integer;
begin
  EqualPosition := AnsiPos('=', LineStr);
  if EqualPosition <= 1 then
  begin
    Result := '';
    Exit;
  end else
  begin
    Result := Copy(LineStr, 1, EqualPosition-1);
  end;
end;

function GetValue(const LineStr: string): string;
var
  EqualPosition: Integer;
begin
  EqualPosition := AnsiPos('=', LineStr);
  if EqualPosition <= 1 then
  begin
    Result := '';
    Exit;
  end else
  begin
    Result := Copy(LineStr, EqualPosition+1, MaxInt);
  end;
end;
//--------------------------

{-------------------------------
//  w[xƁw]xɈ͂܂ꂽ擾
@\:       ́w[xw]x̂鎖͍lȂ(OD)
            ֐Ȃ̂ŌĂяo
            LineStrɂ͉s͊܂܂ȂƂ݂ȂĂ
l:
:       2006/07/08(y) 10:52
//--------------------------}
function GetSection(const LineStr: string): string;
var
  BracketStartPosition, BracketEndPosition: Integer;
begin
  BracketStartPosition  := AnsiPos('[', LineStr);
  BracketEndPosition    := AnsiPos(']', LineStr);
  if (1 <= BracketStartPosition)
    and (BracketStartPosition < BracketEndPosition) then
  begin
    Result := Copy(LineStr, BracketStartPosition+1,
      (BracketEndPosition-1) - (BracketStartPosition+1) + 1 )
  end else
  begin
    Result := '';
  end;
end;

procedure testGetSection;
begin
//  Check('123456', GetSection('  [123456]  '));
//  Check('', GetSection('  ]aa[  '));
//  Check('aa', GetSection(' [aa]aa[  '));
//  Check('', GetSection(' []aa[  '));
//  Check('[aa', GetSection(' [[aa]  '));
end;
//--------------------------

{-------------------------------
//  Init@CɊ֌Wsǂf
@\:
            ֐Ȃ̂ŌĂяo
            LineStrɂ͉s͊܂܂ȂƂ݂ȂĂ
l:
:       2006/07/08(y) 10:52
//--------------------------}
function IsIniCommentLine(const LineStr: string): Boolean;
begin
  Result := False;
  if AnsiPos(';', TrimLeft(LineStr))=1 then
  begin
    Result := True;
  end;
end;

function IsSectionLine(const LineStr: string): Boolean;
var
  BracketStartPosition, BracketEndPosition: Integer;
begin
  Result := False;
  if IsIniCommentLine(LineStr) then Exit;
  BracketStartPosition  := AnsiPos('[', LineStr);
  BracketEndPosition    := AnsiPos(']', LineStr);
  if (1 <= BracketStartPosition)
    and (BracketStartPosition < BracketEndPosition) then
  begin
    Result := True;
  end;
end;

{-------------------------------
//  AccessIniFilepg
@\:       ^u܂܂ĂgȂ
            ^uȂ΃Xy[Xg       
l:       
:       2006/07/08(y) 22:55
//--------------------------}
//function IniTrim(const S: String): String;
//begin
//  if InStr(TAB, S) then
//  begin
//    Result := S;
//  end else
//  begin
//    Result := TrimChar(S, ' ');
//  end;
//end;
//--------------------------

function IsIdentLine(const LineStr: string): Boolean;
begin
  Result := False;
  if IsIniCommentLine(LineStr) then Exit;
  if InStr('=', LineStr) then
  begin
    Result := True;
  end;
end;

function IsIniLine(const LineStr: string): Boolean;
begin
  Result := False;
  if IsSectionLine(LineStr) or IsIdentLine(LineStr) then
  begin
    Result := True;
  end;
end;
//--------------------------

{-------------------------------
//  Init@CANZX֐
@\:       TIniFile݊ł͂Ȃ
            pȂxɎĂ
            ESection/Ident̓CfgĂĂȂǂݎ
            ESection͍sTrimēǂݎ
            ESection[Option]OptionTabgsĂ(TIniFile݊)
            EIdent[=]̑OTrimēǂݎ
            ESection/Ident͑召ʂȂ
            E[Option]JԂƓǂݎȂB(TIniFile݊)
              ݈ʒu킩ȂȂ邵B
            ESectionIdentJԂđ݂Ă
              擪IdenẗʒuΏۂƂ
            ReadString
            EIdent̔f[=]̗LȂ̂
              wIdent=󕶎xƂ`Ȃ󕶎Ԃ
              wIdentx݂̂ȂDefaultԂ
            EValueTrimďo͂
            WriteString
            EIdent̔f[=]̗LȂ̂
              wIdent=xƂ`Ȃ珑
              wIdentx݂̂Ȃ珑܂Ȃ
            ESection/Ident̎w肪召ύXĂĂ
              Init@Cɂ͉eȂ
            EValuȇ召͎w肳ꂽƂɏ
            EValueɂ͑Oɋ󔒂^u܂߂鎖ł
l:
:       2006/07/08(y) 10:52
            2006/08/02()
              p(")tValueɑΉ
//--------------------------}
function TAccessIniFile.AccessString(const Section: string; const Ident: string;
 const Value: string; Strings: TStrings; Access: TIniAccess): string;
var
  i: Integer;
  j: Integer;
  SectionStartLine: Integer;
  WroteFlag: Boolean;
  SectionExistFlag: Boolean;
  SectionTrimFlag: Boolean;
begin
(*-------------------------------
  testGetSection;
//-------------------------------*)
  Result := Value;
  case Access of
   iaRead, iaWrite, iaDeleteKey:
     if (TrimChar(Section, ' ') = EmptyStr) or (TrimChar(Ident, ' ') = EmptyStr) then Exit;
   iaEraseSection:
     if (TrimChar(Section, ' ') = EmptyStr) then Exit;
   iaReadSection:
     if (TrimChar(Section, ' ') = EmptyStr) or (Strings = nil) then Exit;

  end;

  FSections.Add('[]'); try

  SectionExistFlag := False;
  WroteFlag := False;
  SectionStartLine := -1;

  i := 0; while i <= (FSections.Count - 1) do
  begin
    if (SectionStartLine=-1)
      and (AnsiSameText(TrimChar(Section, ' '), Trim(GetSection(FSections[i])))) then
    begin {ZNVJn̏}
      SectionExistFlag := True;
      SectionStartLine := i;
    end else
    if (0<=SectionStartLine)
      and (IsSectionLine(FSections[i])) then
    begin {ZNVȈ}
      {ZNVύXɂȂƂ
         ݂łȂꍇ͑}ď}
      case Access of
      iaWrite:
      begin
        if (WroteFlag = False) then
        begin
          {ݎ͑OInit@CɊ֌Ws
             ̎̍sɑ}}
          {ŏIs̏ꍇ͓삪قȂ(TIniFilẽoOۂ)}
          {XɌƁA̍ŏIs̏TrimĂȂO͒HȂ}
//(*-------------------------------
          if (i = FSections.Count-1) and (Trim(FSections[i-1]) = '') then
          begin
            FSections.Insert(i, TrimChar(Ident, ' ')+'='+Value);
            FSections.Text := FSections.Text;
          end else
//-------------------------------*)
          begin
            j := i; while IsIniLine(FSections[j-1])=False do
            begin
              Dec(j);
            end;
            FSections.Insert(j, TrimChar(Ident, ' ')+'='+Value);
            FSections.Text := FSections.Text;
          end;
        end;
      end;

      iaEraseSection:
      begin
        SectionTrimFlag := False;
        for j := i-1 downto SectionStartLine do
        begin
          if (Trim(FSections[j])=EmptyStr)
            or IsIniCommentLine(Trim(FSections[j])) then
          begin
          end else
          begin
            SectionTrimFlag := True;
          end;

          if SectionTrimFlag then
          begin
            FSections.Delete(j);
            Dec(i);
          end;
        end;
      end;

      iaReadSection:
      begin
        for j := SectionStartLine to i-1 do
        begin
          if IsIdentLine(FSections[j])
            and (Trim(GetName(FSections[j]))<>EmptyStr) then
          begin
            Strings.Add(Trim(GetName(FSections[j]))+'='+
                        OneTrimChar(Trim(GetValue(FSections[j])), '"'));
          end;
        end;
      end;

      end;

      SectionStartLine := -1;
      Exit; {xInSection=TrueɂȂFalseɂȂExit邱Ƃ
               dSection鏈ɂȂ
               ܂[Option]...[Option]ƂȂĂĂ2ڈڍs͖}
    end;

    if 0<=SectionStartLine then
    begin {ZNV̏}
      if AnsiSameText(TrimChar(Ident, ' '), Trim(GetName(FSections[i]))) then
      begin
        case Access of
        iaRead:
        begin
          Result := OneTrimChar(Trim(GetValue(FSections[i])), '"');
          Exit; {xIdentĒl擾Exit邱Ƃ
                   dIdent𖳎鏈ɂȂ}
        end;

        iaWrite:
        begin
          FSections[i] :=
            GetName(FSections[i]) + '='
            +
            Value;
          FSections.Text := FSections.Text;
          WroteFlag := True;
          Exit;
        end;

        iaDeleteKey:
        begin
          FSections.Delete(i);
          Dec(i);
        end;
        end;

      end;
    end;

    Inc(i);
  end;

  if (SectionExistFlag=False) then
  begin
    case Access of
    iaWrite:
    begin
      if (WroteFlag = False) then
      begin
        FSections.Insert(FSections.Count-1,
          '['+TrimChar(Section, ' ')+']');
        FSections.Insert(FSections.Count-1,
          TrimChar(Ident, ' ')+'='+Value);
        FSections.Text := FSections.Text;
      end;
    end;
    end;
  end;


  finally FSections.Delete(FSections.Count-1); end;
end;

function TAccessIniFile.ReadString(const Section, Ident,
  Default: string): string;
begin
  Result := AccessString(Section, Ident, Default, nil, iaRead);
end;

procedure TAccessIniFile.WriteString(const Section, Ident, Value: String);
begin
  AccessString(Section, Ident, Value, nil, iaWrite);
end;

procedure TAccessIniFile.DeleteKey(const Section, Ident: String);
begin
  AccessString(Section, Ident, '', nil, iaDeleteKey);
end;

procedure TAccessIniFile.EraseSection(const Section: string);
begin
  AccessString(Section, '', '', nil, iaEraseSection);
end;
//--------------------------


{-------------------------------
//  ZNV񋓂
@\:
l:
:       2006/07/08(y) 15:35
//--------------------------}
procedure TAccessIniFile.ReadSections(Strings: TStrings);
var
  i: Integer;
  SectionText: String;
begin
  if Assigned(Strings) then
  begin
    Strings.Clear;
    for i := 0 to FSections.Count - 1 do
    begin
      SectionText := Trim( GetSection(FSections[i]) );
      if SectionText <> '' then
        Strings.Add(SectionText);
      {TIniFilẽoOdlΉ
         Sectionꍇŗ񋓂߂
         ɃoOۂ̂ł̍sȂC}
      if IsSectionLine(FSections[i]) and (SectionText='') then Exit;
    end;
  end;
end;
//--------------------------

{-------------------------------
//  Section̒l擾Stringsɏo͂
@\:       ReadSectionValues
              Name=Valuě`ŏo
            ReadSection
              Namě`ŏo
l:
:       2006/07/08(y) 16:02
//--------------------------}
procedure TAccessIniFile.ReadSectionValues(const Section: string;
  Strings: TStrings);
var
  i: Integer;
  LineName: String;
begin
  if Assigned(Strings) then
  begin
    Strings.Clear;
    AccessString(Section, '', '', Strings, iaReadSection);
    for i := 0 to Strings.Count - 1 do
    begin
     LineName := GetName(Strings[i]);
      Strings[i] := LineName+'='+
        Strings.Values[LineName];
    end;
  end;
end;

procedure TAccessIniFile.ReadSection(const Section: string; Strings: TStrings);
var
  i: Integer;
begin
  ReadSectionValues(Section, Strings);
  for i := 0 to Strings.Count - 1 do
  begin
    Strings[i] := GetName(Strings[i]);
  end;
end;
//--------------------------


end.
