unit testIniFileReadStringUnit;

interface

uses
  Classes,
  SysUtils,
  IniFiles,
  Dialogs,

//  StringUnitHeavy,
  AnsiStringFileUnit,
  ExePathUnit,
  
  SystemUnit,
  XPtest;

procedure testIniFileReadString;
 
procedure MakeNormalIniFile;
procedure MakeDuplicationSectionIniFile;
procedure MakeIndentIniFile;
procedure MakeCommentIniFile;
procedure MakeTrimValueIniFile;
procedure MakeTrimSectionIdentIniFile;

implementation

uses AccessIniFile, IniFilEX, NkMemIniFile, testIniWriteStringUnit;

procedure MakeNormalIniFile;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add('[Option]');
  StrList.Add('Name1=Value1');
  StrList.Add('Name2=Value2');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

procedure MakeDuplicationSectionIniFile;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add('[Option]');
  StrList.Add('Name1=Value1');
  StrList.Add('Name2=Value2');
  StrList.Add('[Option]');
  StrList.Add('Name1=Value1');
  StrList.Add('Name2=ValueB');
  StrList.Add('Name3=Value3');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-B');
  StrList.Add('Name3=Value2-3');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

procedure MakeIndentIniFile;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(' [Option1]');     //1
  StrList.Add('Name1=Value1-1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('  [Option2]');   //2
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('Name3=Value2-3');
  StrList.Add('          [Option3]');   //10
  StrList.Add('Name1=Value3-1');
  StrList.Add('Name2=Value3-2');
  StrList.Add('Name3=Value3-3');
  StrList.Add(#9#9'[Option4]');   //^uŎ
  StrList.Add('Name1=Value4-1');
  StrList.Add('Name2=Value4-2');
  StrList.Add('Name3=Value4-3');
  StrList.Add('[Option5]');         //Ident
  StrList.Add(' Name1=Value5-1');
  StrList.Add('     Name2=Value5-2');
  StrList.Add(#9#9'Name3=Value5-3');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

procedure MakeCommentIniFile;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add('');
  StrList.Add('');
  StrList.Add(';Rg');
  StrList.Add('sKvȍs');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=Value1-1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add(';Rg');
  StrList.Add('sKvȍs');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg');
  StrList.Add('sKvȍs');
  StrList.Add('');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

procedure MakeTrimValueIniFile;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=  Value1-1');
  StrList.Add('Name2=Value1-2  ');
  StrList.Add('Name3=     Value1-3     ');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1='#9'Value2-1');
  StrList.Add('Name2=Value2-2'#9);
  StrList.Add('Name3='#9#9'Value2-3'#9#9);
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=  Value3 - 1');
  StrList.Add('Name2=Value3 - 2  ');
  StrList.Add('Name3=     Value3 - 3     ');
  StrList.Add('Name4=     Value3'#9#9'-  4     ');
  StrList.Add('Name5='#9#9'Value3'#9#9'-  5'#9#9);
  StrList.Add('');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

procedure MakeTrimSectionIdentIniFile;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add('[Option1]');
  StrList.Add(' Name1=Value1-1');
  StrList.Add('Name2 =Value1-2');
  StrList.Add('  Name3  =Value1-3');
  StrList.Add(#9#9'Name4'#9#9'=Value1-4');
  StrList.Add(#9#9'  Name5'#9#9'  =Value1-5');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('A Name1=Value2-1');
  StrList.Add('Name2 A=Value2-2');
  StrList.Add('A'#9#9'Name3'#9#9'A=Value2-3');
  StrList.Add('  '#9#9'Name5  '#9#9'=Value2-5');
  StrList.Add('');
  StrList.Add('[ Option3]');
  StrList.Add('Name1=Value3-1');
  StrList.Add('');
  StrList.Add('[Option4 ]');
  StrList.Add('Name1=Value4-1');
  StrList.Add('');
  StrList.Add('['#9'Option5]');
  StrList.Add('Name1=Value5-1');
  StrList.Add('');
  StrList.Add('[Option6'#9#9']');
  StrList.Add('Name1=Value6-1');
  StrList.Add('');
  StrList.Add('[A Option7]');
  StrList.Add('Name1=Value7-1');
  StrList.Add('');
  StrList.Add('[Option8 A]');
  StrList.Add('Name1=Value8-1');
  StrList.Add('');
  StrList.Add('[A'#9#9'Option9]');
  StrList.Add('Name1=Value9-1');
  StrList.Add('');
  StrList.Add('[A'#9#9'Option10'#9#9'A]');
  StrList.Add('Name1=Value10-1');
  StrList.Add('');
  StrList.Add('[  '#9#9'Option11  '#9#9']');
  StrList.Add('Name1=Value11-1');
  StrList.Add('['#9#9'Option12  '#9#9']');
  StrList.Add('Name2=Value12-2');
  StrList.Add('');
  StrList.Add('['#9#9'  Option13'#9#9'  ]');
  StrList.Add('Name1=Value13-1');
  StrList.Add('['#9#9'  Option14'#9#9']');
  StrList.Add('Name2=Value14-2');
  StrList.Add('');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;


procedure testNormalIniFile(Ini: TCustomIniFile);
begin
  with UnitTest do begin
  {܂TIniFile̎dl𗝉}
  Check('Value1', Ini.ReadString('Option', 'Name1', ''));
  Check('Value1', Ini.ReadString('OPTION', 'Name1', ''));
  Check('Value1', Ini.ReadString('Option', 'NAME1', ''));
  Check('Value1', Ini.ReadString('OPTION', 'NAME1', ''));
  {SectionIdent̑召͔fȂƂƂ킩}
  Ini.Free;
  end;
end;

procedure testDuplicationSectionIniFile(Ini: TCustomIniFile);
begin
  with UnitTest do begin
  {dSection̉e`FbN}
  Check('Value1', Ini.ReadString('Option', 'Name1', ''));
  Check('Value2', Ini.ReadString('Option', 'Name2', ''));
  Check('', Ini.ReadString('Option', 'Name3', '')); {Value3͎擾łȂ}
  Check('Value2-1', Ini.ReadString('Option2', 'Name1', ''));
  Check('Value2-B', Ini.ReadString('Option2', 'Name2', ''));
  Check('Value2-3', Ini.ReadString('Option2', 'Name3', ''));
  Ini.Free;
  {dSection̒g͖Ă邱Ƃ킩}
  end;
end;

procedure testIndentIniFile(Ini: TCustomIniFile);
begin
  with UnitTest do begin
  {CfgSection/Ident𖳎邩`FbN}
  Check('Value1-2', Ini.ReadString('Option1', 'Name2', ''));
  Check('Value2-3', Ini.ReadString('Option2', 'Name3', ''));
  Check('Value3-1', Ini.ReadString('Option3', 'Name1', ''));
  Check('Value4-3', Ini.ReadString('Option4', 'Name3', ''));
  Check('Value5-2', Ini.ReadString('Option5', 'Name2', ''));
  Check('Value5-3', Ini.ReadString('Option5', 'Name3', ''));
  Ini.Free;
  {CfgSection/Ident͐ǂݎƂƂ킩}
  end;
end;

procedure testCommentIniFile(Ini: TCustomIniFile);
begin
  with UnitTest do begin
  {sRgs𖳎ł邩`FbN}
  Check('Value1-2', Ini.ReadString('Option1', 'Name2', ''));
  Check('Value2-1', Ini.ReadString('Option2', 'Name1', ''));
  Ini.Free;
  end;
end;

procedure testTrimValueIniFile(Ini: TCustomIniFile);
begin
  with UnitTest do begin
  {Value̋󔒂^uǂݎ邩`FbN}
  Check('Value1-1', Ini.ReadString('Option1', 'Name1', ''));
  Check('Value1-2', Ini.ReadString('Option1', 'Name2', ''));
  Check('Value1-3', Ini.ReadString('Option1', 'Name3', ''));
  Check('Value2-1', Ini.ReadString('Option2', 'Name1', ''));
  Check('Value2-2', Ini.ReadString('Option2', 'Name2', ''));
  Check('Value2-3', Ini.ReadString('Option2', 'Name3', ''));

  Check('Value3 - 1', Ini.ReadString('Option3', 'Name1', ''));
  Check('Value3 - 2', Ini.ReadString('Option3', 'Name2', ''));
  Check('Value3 - 3', Ini.ReadString('Option3', 'Name3', ''));
  Check('Value3'#9#9'-  4', Ini.ReadString('Option3', 'Name4', ''));
  Check('Value3'#9#9'-  5', Ini.ReadString('Option3', 'Name5', ''));
  Ini.Free;
  {ValueTrimďo͂邱Ƃ킩}
  end;
end;

procedure testTrimSectionIdentIniFile(Ini: TCustomIniFile);
begin
  with UnitTest do begin
  {SectionIdent̋󔒂svɂǂΉĂ邩`FbN}
  Check('Value1-1', Ini.ReadString('Option1', 'Name1', ''));
  Check('Value1-2', Ini.ReadString('Option1', 'Name2', ''));
  Check('Value1-3', Ini.ReadString('Option1', 'Name3', ''));
  Check('Value1-4', Ini.ReadString('Option1', 'Name4', ''));
  Check('Value1-5', Ini.ReadString('Option1', 'Name5', ''));
  Check('',         Ini.ReadString('Option1', #9#9'  Name5'#9#9, ''));
  Check('',         Ini.ReadString('Option1', #9#9'  Name5'#9#9'  ', ''));
  Check('Value2-1', Ini.ReadString('Option2', 'A Name1', ''));
  Check('Value2-2', Ini.ReadString('Option2', 'Name2 A', ''));
  Check('Value2-3', Ini.ReadString('Option2', 'A'#9#9'Name3'#9#9'A', ''));
  Check('Value2-5', Ini.ReadString('Option2', 'Name5', ''));
  Check('',         Ini.ReadString('Option2', #9#9'Name5  '#9#9, ''));
  Check('',         Ini.ReadString('Option2', '  '#9#9'Name5  '#9#9, ''));
  Check('Value3-1', Ini.ReadString('Option3', 'Name1', ''));
  Check('Value3-1', Ini.ReadString(' Option3', 'Name1', ''));
  Check('Value4-1', Ini.ReadString('Option4', 'Name1', ''));
  Check('Value4-1', Ini.ReadString('Option4 ', 'Name1', ''));
  Check('Value5-1', Ini.ReadString('Option5', 'Name1', ''));
  Check('',         Ini.ReadString(#9'Option5', 'Name1', ''));
  Check('Value6-1', Ini.ReadString('Option6', 'Name1', ''));
  Check('',         Ini.ReadString('Option6'#9#9, 'Name1', ''));
  Check('Value7-1', Ini.ReadString('A Option7', 'Name1', ''));
  Check('Value8-1', Ini.ReadString('Option8 A', 'Name1', ''));
  Check('Value9-1', Ini.ReadString('A'#9#9'Option9', 'Name1', ''));
  Check('Value10-1',Ini.ReadString('A'#9#9'Option10'#9#9'A', 'Name1', ''));

  Check('Value11-1',Ini.ReadString('Option11', 'Name1', ''));
  Check('Value11-1',Ini.ReadString('Option11 ', 'Name1', ''));
  Check('Value11-1',Ini.ReadString('Option11  ', 'Name1', ''));
  Check('Value11-1',Ini.ReadString('Option11          ', 'Name1', ''));
  Check('Value11-1',Ini.ReadString('  Option11', 'Name1', ''));
  Check('Value11-1',Ini.ReadString(' Option11', 'Name1', ''));
  Check('Value11-1',Ini.ReadString('          Option11', 'Name1', ''));
  Check('',         Ini.ReadString('  '#9#9'Option11  ', 'Name1', ''));
  Check('',         Ini.ReadString('  '#9#9'Option11  '#9#9, 'Name1', ''));
  Check('Value12-2',Ini.ReadString('Option12', 'Name2', ''));
  Check('Value12-2',Ini.ReadString('Option12 ', 'Name2', ''));
  Check('Value12-2',Ini.ReadString('Option12  ', 'Name2', ''));
  Check('Value12-2',Ini.ReadString('Option12          ', 'Name2', ''));
  Check('Value12-2',Ini.ReadString('  Option12', 'Name2', ''));
  Check('Value12-2',Ini.ReadString(' Option12', 'Name2', ''));
  Check('Value12-2',Ini.ReadString('          Option12', 'Name2', ''));
  Check('',         Ini.ReadString(#9#9'Option12  '#9#9, 'Name2', ''));
  Check('Value13-1',Ini.ReadString('Option13', 'Name1', ''));
  Check('Value13-1',Ini.ReadString('Option13 ', 'Name1', ''));
  Check('Value13-1',Ini.ReadString('Option13  ', 'Name1', ''));
  Check('Value13-1',Ini.ReadString('Option13          ', 'Name1', ''));
  Check('Value13-1',Ini.ReadString('  Option13', 'Name1', ''));
  Check('Value13-1',Ini.ReadString(' Option13', 'Name1', ''));
  Check('Value13-1',Ini.ReadString('          Option13', 'Name1', ''));
  Check('',         Ini.ReadString('Option13'#9#9, 'Name1', ''));
  Check('',         Ini.ReadString(#9#9'  Option13', 'Name1', ''));
  Check('',         Ini.ReadString(#9#9'  Option13'#9#9'  ', 'Name1', ''));
  Check('Value14-2',Ini.ReadString('Option14', 'Name2', ''));
  Check('Value14-2',Ini.ReadString('Option14 ', 'Name2', ''));
  Check('Value14-2',Ini.ReadString('Option14  ', 'Name2', ''));
  Check('Value14-2',Ini.ReadString('Option14          ', 'Name2', ''));
  Check('Value14-2',Ini.ReadString('  Option14', 'Name2', ''));
  Check('Value14-2',Ini.ReadString(' Option14', 'Name2', ''));
  Check('Value14-2',Ini.ReadString('          Option14', 'Name2', ''));
  Check('',         Ini.ReadString('Option14'#9#9, 'Name2', ''));
  Check('',         Ini.ReadString('  Option14'#9#9'  ', 'Name2', ''));
  Check('',         Ini.ReadString(#9#9'  Option14'#9#9'  ', 'Name2', ''));
  Ini.Free;
  {IdentTrimASection̓^uTrim邱Ƃ킩}
  end;
end;

procedure testSpaceTabSectionIniFile(Ini: TCustomIniFile);
begin
  with UnitTest do begin
  {SectionIdent̋󔒂svɂǂΉĂ邩`FbN}
  if not (Ini is TIniFile) then
  begin
    Check(False, 'ValueN-1'=Ini.ReadString('', 'Name1', ''));
    Check(False, 'ValueS-2'=Ini.ReadString('   ', 'Name2', ''));
    Check(False, 'ValueTST-1'=Ini.ReadString(' ', 'Name1', ''));
    Check('',       Ini.ReadString('', 'Name1', ''));
    Check('',       Ini.ReadString('   ', 'Name2', ''));
    Check('',       Ini.ReadString(' ', 'Name1', ''));
  end;
  Check(False, 'ValueTT-3'=Ini.ReadString('#9#9', 'Name1', ''));
  Check(False, 'ValueTST-4'=Ini.ReadString(#9' '#9, 'Name2', ''));
  Check(False, 'ValueSTTTS-1'=Ini.ReadString(' '#9#9#9' ', 'Name1', ''));
  Check(False, 'ValueSTTTS-2'=Ini.ReadString(#9#9#9, 'Name2', ''));
  Check('',         Ini.ReadString('#9#9', 'Name1', ''));
  Check('',         Ini.ReadString(#9' '#9, 'Name2', ''));
  Check('',         Ini.ReadString(' '#9#9#9' ', 'Name1', ''));
  Check('',         Ini.ReadString(#9#9#9, 'Name2', ''));
  Ini.Free;
  {IdentTrimASection̓^uTrim邱Ƃ킩}
  end;
end;

procedure testEmptyIdentIniFile(Ini: TCustomIniFile);
begin
  with UnitTest do begin
  {SectionIdent̋󔒂svɂǂΉĂ邩`FbN}
  if not (Ini is TIniFile) then
  begin
    Check('',       Ini.ReadString('Option1', '', ''));
  end;
  Check('',         Ini.ReadString('Option1', #9#9, ''));
  Check('',         Ini.ReadString('Option1', #9, ''));
  Check('CR[',     Ini.ReadString('Option1', 'svs', ''));
  Check('CR[',    Ini.ReadString('Option1', ' svs', ''));
  Ini.Free;
  {IdentTrimASection̓^uTrim邱Ƃ킩}
  end;
end;

procedure testIniFileReadString;
var
  MsgShow: Boolean;

  procedure ShowMessageShow(Msg: string);
  begin
    if MsgShow then
      ShowMessage(Msg);
  end;

begin
  MsgShow := False;
  UnitTest.AssertSwitch := True;
  UnitTest.Initialize; UnitTest.WriteLog(TIniFile.ClassName);
    MakeNormalIniFile;            testNormalIniFile(TIniFile.Create(AppIniFilePath));
    MakeDuplicationSectionIniFile;testDuplicationSectionIniFile(TIniFile.Create(AppIniFilePath));
    MakeIndentIniFile;            testIndentIniFile(TIniFile.Create(AppIniFilePath));
    MakeCommentIniFile;           testCommentIniFile(TIniFile.Create(AppIniFilePath));
    MakeTrimValueIniFile;         testTrimValueIniFile(TIniFile.Create(AppIniFilePath));
  UnitTest.Finalize; ShowMessageShow(UnitTest.LogText);
  UnitTest.Initialize; UnitTest.WriteLog(TIniFile.ClassName);
    MakeTrimSectionIdentIniFile;  testTrimSectionIdentIniFile(TIniFile.Create(AppIniFilePath));
  UnitTest.Finalize; ShowMessageShow(UnitTest.LogText);
  UnitTest.Initialize; UnitTest.WriteLog(TIniFile.ClassName);
    MakeIniFileSpaceTabSection;   testSpaceTabSectionIniFile(TIniFile.Create(AppIniFilePath));
  SaveStringToFile(AppIniFilePath, ResultIniFile);
    testEmptyIdentIniFile(TIniFile.Create(AppIniFilePath));
  UnitTest.Finalize; ShowMessageShow(UnitTest.LogText);

  UnitTest.Initialize; UnitTest.WriteLog(TAccessIniFile.ClassName);
    MakeNormalIniFile;            testNormalIniFile(TAccessIniFile.Create(AppIniFilePath));
    MakeDuplicationSectionIniFile;testDuplicationSectionIniFile(TAccessIniFile.Create(AppIniFilePath));
    MakeIndentIniFile;            testIndentIniFile(TAccessIniFile.Create(AppIniFilePath));
    MakeCommentIniFile;           testCommentIniFile(TAccessIniFile.Create(AppIniFilePath));
    MakeTrimValueIniFile;         testTrimValueIniFile(TAccessIniFile.Create(AppIniFilePath));
  UnitTest.Finalize; ShowMessageShow(UnitTest.LogText);
  UnitTest.Initialize; UnitTest.WriteLog(TAccessIniFile.ClassName);
    MakeTrimSectionIdentIniFile;  testTrimSectionIdentIniFile(TAccessIniFile.Create(AppIniFilePath));
  UnitTest.Finalize; ShowMessageShow(UnitTest.LogText);
  UnitTest.Initialize; UnitTest.WriteLog(TAccessIniFile.ClassName);
    MakeIniFileSpaceTabSection;   testSpaceTabSectionIniFile(TAccessIniFile.Create(AppIniFilePath));
  SaveStringToFile(AppIniFilePath, ResultIniFile);
    testEmptyIdentIniFile(TAccessIniFile.Create(AppIniFilePath));
  UnitTest.Finalize; ShowMessageShow(UnitTest.LogText);

end;


end.
