unit testIniValueUnit;

interface

uses
  Classes,
  SysUtils,
  IniFiles,
  Dialogs,

//  StringUnitHeavy,
  AnsiStringFileUnit,
  ExePathUnit,
  SystemUnit,
  XPtest;

procedure testIniValue;


implementation

uses AccessIniFile;

procedure MakeQuoteValueIniFile;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add('[Section1]');
  StrList.Add('aaa= "bbb""ccc"  ');
  StrList.Add('bbb="bbb""ccc"  ');
  StrList.Add('ccc="bbb""ccc"');
  StrList.Add('ddd="bbb"ccc"');

  StrList.Add('eee=" bbb""ccc  "');
  StrList.Add('fff=" "bbb""ccc"  "');
  StrList.Add('ggg= " "bbb""ccc"  " ');
  StrList.Add('hhh= """bbb""ccc"""  ');
  StrList.Add('iii= """bbb""ccc"  ');
  StrList.Add('jjj= "bbb""ccc"""  ');
  StrList.Add('kkk="bbb"');
  StrList.Add('lll="bbb');
  StrList.Add('mmm=bbb"');
  StrList.Add('nnn="bbb""ccc"');
  StrList.Add('ooo=bbb""ccc"');
  StrList.Add('ppp="bbb""ccc');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;


procedure testQuoteValueIniFile(Ini: TCustomIniFile);
begin
  with UnitTest do begin
  Check('bbb""ccc', Ini.ReadString('Section1', 'aaa', ''));
  Check('bbb""ccc', Ini.ReadString('Section1', 'bbb', ''));
  Check('bbb""ccc', Ini.ReadString('Section1', 'ccc', ''));
  Check('bbb"ccc', Ini.ReadString('Section1', 'ddd', ''));

  Check(' bbb""ccc  ', Ini.ReadString('Section1', 'eee', ''));
  Check(' "bbb""ccc"  ', Ini.ReadString('Section1', 'fff', ''));
  Check(' "bbb""ccc"  ', Ini.ReadString('Section1', 'ggg', ''));
  Check('""bbb""ccc""', Ini.ReadString('Section1', 'hhh', ''));
  Check('""bbb""ccc', Ini.ReadString('Section1', 'iii', ''));
  Check('bbb""ccc""', Ini.ReadString('Section1', 'jjj', ''));
  {l擾ꍇ̓Xy[Xg
     quart=pĒlƂĎ擾Ƃ삪mFł}

  Check('bbb', Ini.ReadString('Section1', 'kkk', ''));
  Check('"bbb', Ini.ReadString('Section1', 'lll', ''));
  Check('bbb"', Ini.ReadString('Section1', 'mmm', ''));
  Check('bbb""ccc', Ini.ReadString('Section1', 'nnn', ''));
  Check('bbb""ccc"', Ini.ReadString('Section1', 'ooo', ''));
  Check('"bbb""ccc', Ini.ReadString('Section1', 'ppp', ''));

  Ini.Free;
  end;           
end;

procedure MakeCommentValueIniFile;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add('[Section1]');
  StrList.Add('Name1=Value1-1;Rg');
  StrList.Add('Name2=Value1-2  ;Rg');
  StrList.Add('Name3="Value1-3";Rg');
  StrList.Add('Name4="Value1-4"   ;Rg');
  StrList.Add('Name5="Value1-5"   ;Rg"');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;


procedure testCommentValueIniFile(Ini: TCustomIniFile);
begin
  with UnitTest do begin
  Check('Value1-1;Rg',        Ini.ReadString('Section1', 'Name1', ''));
  Check('Value1-2  ;Rg',      Ini.ReadString('Section1', 'Name2', ''));
  Check('"Value1-3";Rg',      Ini.ReadString('Section1', 'Name3', ''));
  Check('"Value1-4"   ;Rg',   Ini.ReadString('Section1', 'Name4', ''));
  Check('Value1-5"   ;Rg',    Ini.ReadString('Section1', 'Name5', ''));

  Ini.Free;
  end;
end;

procedure testIniValue;
var
  MsgShow: Boolean;

  procedure ShowMessageShow(Msg: string);
  begin
    if MsgShow then
      ShowMessage(Msg);
  end;

begin
  MsgShow := False;
  UnitTest.AssertSwitch := True;

  UnitTest.Initialize; UnitTest.WriteLog(TIniFile.ClassName);
    MakeQuoteValueIniFile;      testQuoteValueIniFile(TIniFile.Create(AppIniFilePath));
  UnitTest.Finalize; ShowMessageShow(UnitTest.LogText);

  UnitTest.Initialize; UnitTest.WriteLog(TAccessIniFile.ClassName);
    MakeQuoteValueIniFile;      testQuoteValueIniFile(TAccessIniFile.Create(AppIniFilePath));
  UnitTest.Finalize; ShowMessageShow(UnitTest.LogText);

  UnitTest.Initialize; UnitTest.WriteLog(TIniFile.ClassName);
    MakeCommentValueIniFile;      testCommentValueIniFile(TIniFile.Create(AppIniFilePath));
  UnitTest.Finalize; ShowMessageShow(UnitTest.LogText);

  UnitTest.Initialize; UnitTest.WriteLog(TAccessIniFile.ClassName);
    MakeCommentValueIniFile;      testCommentValueIniFile(TAccessIniFile.Create(AppIniFilePath));
  UnitTest.Finalize; ShowMessageShow(UnitTest.LogText);

end;



end.
