unit testIniWriteStringUnit;

interface
uses
  Windows,
  Classes,
  SysUtils,
  IniFiles,
  Dialogs,
  Math,

  FileUnit,
//  StringUnitHeavy,
  AnsiStringFileUnit,
  ExePathUnit,

  SystemUnit,
  XPtest;

procedure testIniWriteString;

procedure MakeIniFileHoldComment1;
procedure MakeIniFileHoldComment2;
procedure MakeIniFileHoldComment3;
procedure MakeIniFileHoldComment4;
procedure MakeIniFileSpaceTabSection;
procedure MakeIniFileEmptySection;
function ResultIniFile: String;
function ResultIniFile2: String;
function ResultIniFile3: String;
function ResultIniFile4: String;
function ResultIniFileSpaceTabSection: String;
function ResultIniFileEmptySection: String;

implementation

uses AccessIniFile, IniFilEX, NkMemIniFile, Unit1;

procedure MakeIniFileHoldComment1;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=Value1-1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;


procedure testIniFileHoldComment1(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  Ini.WriteString('Option1', 'Name1', 'VALUE1');
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := StringReplace(BeforeWriteString, 'Value1-1', 'VALUE1', []);
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;

procedure testIniFileHoldComment2(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  Ini.WriteString('Option1', 'Name1', 'VALUE1');
  Ini.WriteString('Option2', 'Name2',
    AnsiUpperCase(Ini.ReadString('Option2', 'Name2', '')));
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := StringReplace(BeforeWriteString, 'Value1-1', 'VALUE1', []);
  BeforeWriteString := StringReplace(BeforeWriteString, 'Value2-2', 'VALUE2-2', []);
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;

procedure testIniFileHoldComment3(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  Ini.WriteString('Option1', 'Name1', '  VALUE1  ');
  Ini.WriteString('Option2', 'Name2', #9'value2'#9);
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := StringReplace(BeforeWriteString, 'Value1-1', '  VALUE1  ', []);
  BeforeWriteString := StringReplace(BeforeWriteString, 'Value2-2', #9'value2'#9, []);
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;


const TimerMiliSec: Integer = 100;

procedure testIniFileNoUpdate(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
  BeforeFileDateTime: TDateTime;
  AfterFileDateTime: TDateTime;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  BeforeFileDateTime := GetFileFolderDateTimes(AppIniFilePath).Modify;
  Sleep(TimerMiliSec);
  Ini.WriteString('Option1', 'Name1',
    Ini.ReadString('Option1', 'Name1', ''));
  Ini.WriteString('Option2', 'Name2',
    Ini.ReadString('Option2', 'Name2', ''));
  Sleep(TimerMiliSec);
  Ini.UpdateFile;
  Ini.Free;

  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  AfterFileDateTime := GetFileFolderDateTimes(AppIniFilePath).Modify;
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  Check(BeforeFileDateTime, AfterFileDateTime);
  end;
end;

function ResultIniFile: String;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=VALUE1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('Name3=VALUE1-3');
  StrList.Add('Name5=value1-5');
  StrList.Add(#9#9'=tabValue');
  StrList.Add(#9'=tabspaceValue');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=value2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('Name4=value2-4');
  StrList.Add('Name3=value2-3');
  Result := StrList.Text;
  StrList.Free;
end;

procedure testIniFileNewItem(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  Ini.WriteString('Option1', 'Name1', 'VALUE1');
  Ini.WriteString('Option1', 'Name3', 'VALUE1-3');
  Ini.WriteString('Option1', 'Name5', 'value1-5');
  Ini.WriteString('Option2', 'Name4', 'value2-4');
  Ini.WriteString('Option2', 'Name2', 'value2');
  Ini.WriteString('Option2', 'Name3', 'value2-3');
  if not (Ini is TIniFile) then
  begin
    {TIniFileIdentɋ󕶎
       W[ 'ntdll.dll' ̃AhX 7C953144 ŃAhX 0040544D ɑ΂鏑݈ᔽ܂B.
       ƂG[ł܂}
    Ini.WriteString('Option1', '', 'nullValue');
    Ini.WriteString('Option1', ' ', 'spaceValue');
  end;
  Ini.WriteString('Option1', #9#9, 'tabValue');
  Ini.WriteString('Option1', ' '#9' ', 'tabspaceValue');
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := ResultIniFile;
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;

procedure MakeIniFileHoldComment2;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=Value1-1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=Value3-1');
  StrList.Add('Name2=Value3-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

function ResultIniFile2: String;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add('Name0=Value0-0');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=VALUE1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('Name3=VALUE1-3');
  StrList.Add('Name5=value1-5');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=value2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('Name4=value2-4');
  StrList.Add('Name3=value2-3');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=VALUE1');
  StrList.Add('Name2=Value3-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('Name3=VALUE3-3');
  StrList.Add('Name5=5-3');
  StrList.Add('[Option4]');
  StrList.Add('Name1=Value4-1');
  Result := StrList.Text;
  StrList.Free;
end;

procedure testIniFileNewItem2(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  Ini.WriteString('Option1', 'Name1', 'VALUE1');
  Ini.WriteString('Option1', 'Name3', 'VALUE1-3');
  Ini.WriteString('Option1', 'Name5', 'value1-5');
  Ini.WriteString('Option2', 'Name4', 'value2-4');
  Ini.WriteString('Option2', 'Name2', 'value2');
  Ini.WriteString('Option2', 'Name3', 'value2-3');
  Ini.WriteString('Option3', 'Name1', 'VALUE1');
  Ini.WriteString('Option3', 'Name3', 'VALUE3-3');
  Ini.WriteString('Option3', 'Name5', 'value3-5');
  Ini.WriteString('Option3', 'Name5', '5-3');
  Ini.WriteString('Option0', 'Name0', 'Value0-0');
  Ini.WriteString('Option4', 'Name1', 'Value4-1');
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := ResultIniFile2;
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;

procedure MakeIniFileHoldComment3;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=Value1-1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=Value3-1');
  StrList.Add('Name2=Value3-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

function ResultIniFile3: String;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=VALUE1');
  StrList.Add('Name2=VALUE2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add(#9#9'Name1=VALUE3');
  StrList.Add('Name2'#9#9'=VALUE4');
  StrList.Add(#9#9'  Name2'#9#9'=VALUE10');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=VALUE5');
  StrList.Add('Name2=VALUE6');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add(#9#9'Name1=VALUE7');
  StrList.Add('Name2'#9#9'=VALUE8');
  StrList.Add(#9#9'Name1  '#9#9'=VALUE9');
  StrList.Add('[Option4]');
  StrList.Add(#9#9'Name1  '#9#9'=VALUE11');
  StrList.Add(#9#9'  Name2'#9#9'=VALUE12');
  Result := StrList.Text;
  StrList.Free;
end;

procedure testIniFileWriteTrimIdent(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  Ini.WriteString('Option1', ' Name1', 'VALUE1');
  Ini.WriteString('Option1', 'Name2 ', 'VALUE2');
  Ini.WriteString('Option2', #9#9'Name1', 'VALUE3');
  Ini.WriteString('Option2', 'Name2'#9#9, 'VALUE4');
  Ini.WriteString('Option3', ' Name1', 'VALUE5');
  Ini.WriteString('Option3', 'Name2 ', 'VALUE6');
  Ini.WriteString('Option3', #9#9'Name1', 'VALUE7');
  Ini.WriteString('Option3', 'Name2'#9#9, 'VALUE8');
  Ini.WriteString('Option3', '  '#9#9'Name1  '#9#9, 'VALUE9');
  Ini.WriteString('Option2', #9#9'  Name2'#9#9'  ', 'VALUE10');
  Ini.WriteString('Option4', '  '#9#9'Name1  '#9#9, 'VALUE11');
  Ini.WriteString('Option4', #9#9'  Name2'#9#9'  ', 'VALUE12');
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := ResultIniFile3;
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;

procedure MakeIniFileHoldComment3_1;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=Value1-1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=Value3-1');
  StrList.Add('Name2=Value3-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(#9);
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

function ResultIniFile3_1: String;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=VALUE1');
  StrList.Add('Name2=VALUE2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add(#9#9'Name1=VALUE3');
  StrList.Add('Name2'#9#9'=VALUE4');
  StrList.Add(#9#9'  Name2'#9#9'=VALUE10');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=VALUE5');
  StrList.Add('Name2=VALUE6');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(#9);
  StrList.Add(#9#9'Name1=VALUE7');
  StrList.Add('Name2'#9#9'=VALUE8');
  StrList.Add(#9#9'Name1  '#9#9'=VALUE9');
  StrList.Add('[Option4]');
  StrList.Add(#9#9'Name1  '#9#9'=VALUE11');
  StrList.Add(#9#9'  Name2'#9#9'=VALUE12');
  Result := StrList.Text;
  StrList.Free;
end;

procedure testIniFileWriteTrimIdent_1(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  Ini.WriteString('Option1', ' Name1', 'VALUE1');
  Ini.WriteString('Option1', 'Name2 ', 'VALUE2');
  Ini.WriteString('Option2', #9#9'Name1', 'VALUE3');
  Ini.WriteString('Option2', 'Name2'#9#9, 'VALUE4');
  Ini.WriteString('Option3', ' Name1', 'VALUE5');
  Ini.WriteString('Option3', 'Name2 ', 'VALUE6');
  Ini.WriteString('Option3', #9#9'Name1', 'VALUE7');
  Ini.WriteString('Option3', 'Name2'#9#9, 'VALUE8');
  Ini.WriteString('Option3', '  '#9#9'Name1  '#9#9, 'VALUE9');
  Ini.WriteString('Option2', #9#9'  Name2'#9#9'  ', 'VALUE10');
  Ini.WriteString('Option4', '  '#9#9'Name1  '#9#9, 'VALUE11');
  Ini.WriteString('Option4', #9#9'  Name2'#9#9'  ', 'VALUE12');
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := ResultIniFile3_1;
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;


procedure MakeIniFileHoldComment3_2;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=Value1-1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=Value3-1');
  StrList.Add('Name2=Value3-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('    ');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

function ResultIniFile3_2: String;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=VALUE1');
  StrList.Add('Name2=VALUE2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add(#9#9'Name1=VALUE3');
  StrList.Add('Name2'#9#9'=VALUE4');
  StrList.Add(#9#9'  Name2'#9#9'=VALUE10');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=VALUE5');
  StrList.Add('Name2=VALUE6');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('    ');
  StrList.Add(#9#9'Name1=VALUE7');
  StrList.Add('Name2'#9#9'=VALUE8');
  StrList.Add(#9#9'Name1  '#9#9'=VALUE9');
  StrList.Add('[Option4]');
  StrList.Add(#9#9'Name1  '#9#9'=VALUE11');
  StrList.Add(#9#9'  Name2'#9#9'=VALUE12');
  Result := StrList.Text;
  StrList.Free;
end;

procedure testIniFileWriteTrimIdent_2(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  Ini.WriteString('Option1', ' Name1', 'VALUE1');
  Ini.WriteString('Option1', 'Name2 ', 'VALUE2');
  Ini.WriteString('Option2', #9#9'Name1', 'VALUE3');
  Ini.WriteString('Option2', 'Name2'#9#9, 'VALUE4');
  Ini.WriteString('Option3', ' Name1', 'VALUE5');
  Ini.WriteString('Option3', 'Name2 ', 'VALUE6');
  Ini.WriteString('Option3', #9#9'Name1', 'VALUE7');
  Ini.WriteString('Option3', 'Name2'#9#9, 'VALUE8');
  Ini.WriteString('Option3', '  '#9#9'Name1  '#9#9, 'VALUE9');
  Ini.WriteString('Option2', #9#9'  Name2'#9#9'  ', 'VALUE10');
  Ini.WriteString('Option4', '  '#9#9'Name1  '#9#9, 'VALUE11');
  Ini.WriteString('Option4', #9#9'  Name2'#9#9'  ', 'VALUE12');
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := ResultIniFile3_2;
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;



procedure MakeIniFileHoldComment3_3;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=Value1-1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=Value3-1');
  StrList.Add('Name2=Value3-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('    ');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

function ResultIniFile3_3: String;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=VALUE1');
  StrList.Add('Name2=VALUE2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add(#9#9'Name1=VALUE3');
  StrList.Add('Name2'#9#9'=VALUE4');
  StrList.Add(#9#9'  Name2'#9#9'=VALUE10');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=VALUE5');
  StrList.Add('Name2=VALUE6');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add(#9#9'Name1=VALUE7');
  StrList.Add('Name2'#9#9'=VALUE8');
  StrList.Add(#9#9'Name1  '#9#9'=VALUE9');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('    ');
  StrList.Add('[Option4]');
  StrList.Add(#9#9'Name1  '#9#9'=VALUE11');
  StrList.Add(#9#9'  Name2'#9#9'=VALUE12');
  Result := StrList.Text;
  StrList.Free;
end;

procedure testIniFileWriteTrimIdent_3(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  Ini.WriteString('Option1', ' Name1', 'VALUE1');
  Ini.WriteString('Option1', 'Name2 ', 'VALUE2');
  Ini.WriteString('Option2', #9#9'Name1', 'VALUE3');
  Ini.WriteString('Option2', 'Name2'#9#9, 'VALUE4');
  Ini.WriteString('Option3', ' Name1', 'VALUE5');
  Ini.WriteString('Option3', 'Name2 ', 'VALUE6');
  Ini.WriteString('Option3', #9#9'Name1', 'VALUE7');
  Ini.WriteString('Option3', 'Name2'#9#9, 'VALUE8');
  Ini.WriteString('Option3', '  '#9#9'Name1  '#9#9, 'VALUE9');
  Ini.WriteString('Option2', #9#9'  Name2'#9#9'  ', 'VALUE10');
  Ini.WriteString('Option4', '  '#9#9'Name1  '#9#9, 'VALUE11');
  Ini.WriteString('Option4', #9#9'  Name2'#9#9'  ', 'VALUE12');
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := ResultIniFile3_3;
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;


procedure MakeIniFileHoldComment3_4;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=Value1-1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=Value3-1');
  StrList.Add('Name2=Value3-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('   '#9#9' '#9#9);
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

function ResultIniFile3_4: String;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=VALUE1');
  StrList.Add('Name2=VALUE2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add(#9#9'Name1=VALUE3');
  StrList.Add('Name2'#9#9'=VALUE4');
  StrList.Add(#9#9'  Name2'#9#9'=VALUE10');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=VALUE5');
  StrList.Add('Name2=VALUE6');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('   '#9#9' '#9#9);
  StrList.Add(#9#9'Name1=VALUE7');
  StrList.Add('Name2'#9#9'=VALUE8');
  StrList.Add(#9#9'Name1  '#9#9'=VALUE9');
  StrList.Add('[Option4]');
  StrList.Add(#9#9'Name1  '#9#9'=VALUE11');
  StrList.Add(#9#9'  Name2'#9#9'=VALUE12');
  Result := StrList.Text;
  StrList.Free;
end;

procedure testIniFileWriteTrimIdent_4(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  Ini.WriteString('Option1', ' Name1', 'VALUE1');
  Ini.WriteString('Option1', 'Name2 ', 'VALUE2');
  Ini.WriteString('Option2', #9#9'Name1', 'VALUE3');
  Ini.WriteString('Option2', 'Name2'#9#9, 'VALUE4');
  Ini.WriteString('Option3', ' Name1', 'VALUE5');
  Ini.WriteString('Option3', 'Name2 ', 'VALUE6');
  Ini.WriteString('Option3', #9#9'Name1', 'VALUE7');
  Ini.WriteString('Option3', 'Name2'#9#9, 'VALUE8');
  Ini.WriteString('Option3', '  '#9#9'Name1  '#9#9, 'VALUE9');
  Ini.WriteString('Option2', #9#9'  Name2'#9#9'  ', 'VALUE10');
  Ini.WriteString('Option4', '  '#9#9'Name1  '#9#9, 'VALUE11');
  Ini.WriteString('Option4', #9#9'  Name2'#9#9'  ', 'VALUE12');
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := ResultIniFile3_4;
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;


procedure MakeIniFileHoldComment4;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=Value1-1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=Value3-1');
  StrList.Add('Name2=Value3-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

function ResultIniFile4: String;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[Option0]');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=VALUE1');
  StrList.Add('Name2=VALUE2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=VALUE5');
  StrList.Add('Name2=VALUE6');
  StrList.Add('');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('');
  StrList.Add('['#9#9'Option2]');
  StrList.Add('Name1=VALUE3');
  StrList.Add('[Option2'#9#9']');
  StrList.Add('Name2=VALUE4');
  StrList.Add('['#9#9'Option3]');
  StrList.Add('Name1=VALUE7');
  StrList.Add('[Option3'#9#9']');
  StrList.Add('Name2=VALUE8');
  StrList.Add('['#9#9'Option3  '#9#9']');
  StrList.Add('Name1=VALUE9');
  StrList.Add('['#9#9'  Option2'#9#9']');
  StrList.Add('Name2=VALUE10');
  StrList.Add('['#9#9'Option4  '#9#9']');
  StrList.Add('Name1=VALUE11');
  StrList.Add('['#9#9'  Option4'#9#9']');
  StrList.Add('Name2=VALUE12');
  StrList.Add('['#9#9'Option4  '#9#9']');
  StrList.Add('Name3=VALUE13');
  StrList.Add('['#9#9'  Option4'#9#9']');
  StrList.Add('Name4=VALUE14');

  Result := StrList.Text;
  StrList.Free;
end;

procedure testIniFileWriteTrimSection(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  Ini.WriteString(' Option1', 'Name1', 'VALUE1');
  Ini.WriteString('Option1 ', 'Name2', 'VALUE2');
  Ini.WriteString(#9#9'Option2', 'Name1', 'VALUE3');
  Ini.WriteString('Option2'#9#9, 'Name2', 'VALUE4');
  Ini.WriteString(' Option3', 'Name1', 'VALUE5');
  Ini.WriteString('Option3 ', 'Name2', 'VALUE6');
  Ini.WriteString(#9#9'Option3', 'Name1', 'VALUE7');
  Ini.WriteString('Option3'#9#9, 'Name2', 'VALUE8');
  Ini.WriteString('  '#9#9'Option3  '#9#9, 'Name1', 'VALUE9');
  Ini.WriteString(#9#9'  Option2'#9#9'  ', 'Name2', 'VALUE10');
  Ini.WriteString('  '#9#9'Option4  '#9#9, 'Name1', 'VALUE11');
  Ini.WriteString(#9#9'  Option4'#9#9'  ', 'Name2', 'VALUE12');
  Ini.WriteString(#9#9'Option4  '#9#9, 'Name3', 'VALUE13');
  Ini.WriteString(#9#9'  Option4'#9#9, 'Name4', 'VALUE14');
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := ResultIniFile4;
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;

procedure MakeIniFileSpaceTabSection;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[]');
  StrList.Add('Name1=ValueN-1');
  StrList.Add('Name2=ValueN-2');
  StrList.Add('');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[   ]');
  StrList.Add('Name1=ValueS-1');
  StrList.Add('Name2=ValueS-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('['#9#9']');
  StrList.Add('Name1=ValueTT-1');
  StrList.Add('Name2=ValueTT-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('['#9' '#9']');
  StrList.Add('Name1=ValueTST-1');
  StrList.Add('Name2=ValueTST-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[ '#9#9#9' ]');
  StrList.Add('Name1=ValueSTTTS-1');
  StrList.Add('Name2=ValueSTTTS-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

function ResultIniFileSpaceTabSection: String;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[]');
  StrList.Add('Name1=ValueN-1');
  StrList.Add('Name2=ValueN-2');
  StrList.Add('');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[   ]');
  StrList.Add('Name1=ValueS-1');
  StrList.Add('Name2=ValueS-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('['#9#9']');
  StrList.Add('Name1=ValueTT-1');
  StrList.Add('Name2=ValueTT-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('['#9' '#9']');
  StrList.Add('Name1=ValueTST-1');
  StrList.Add('Name2=ValueTST-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[ '#9#9#9' ]');
  StrList.Add('Name1=ValueSTTTS-1');
  StrList.Add('Name2=ValueSTTTS-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('['#9#9']');
  StrList.Add('Name1=VALUETT-1');
  StrList.Add('['#9#9']');
  StrList.Add('Name2=VALUETT-2');
  StrList.Add('['#9#9']');
  StrList.Add('Name3=VALUETT-3');
  StrList.Add('['#9' '#9']');
  StrList.Add('Name1=VALUETST-1');
  StrList.Add('['#9' '#9']');
  StrList.Add('Name2=VALUETST-2');
  StrList.Add('['#9' '#9']');
  StrList.Add('Name3=VALUETST-3');
  StrList.Add('['#9#9#9']');
  StrList.Add('Name1=VALUESTTTS-1');
  StrList.Add('['#9#9#9']');
  StrList.Add('Name2=VALUESTTTS-2');
  StrList.Add('['#9#9#9']');
  StrList.Add('Name3=VALUESTTTS-3');
  Result := StrList.Text;
  StrList.Free;
end;

procedure testIniFileWriteSpaceTabSection(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  if not (Ini is TIniFile) then
  begin
    {TIniFileIdentɋ󕶎
       W[ 'ntdll.dll' ̃AhX 7C953144 ŃAhX 0040544D ɑ΂鏑݈ᔽ܂B.
       ƂG[ł܂}
    Ini.WriteString('', 'Name1', 'VALUEN-1');
    Ini.WriteString('', 'Name2', 'VALUEN-2');
    Ini.WriteString('', 'Name3', 'VALUEN-3');
    Ini.WriteString('   ', 'Name1', 'VALUES-1');
    Ini.WriteString('   ', 'Name2', 'VALUES-2');
    Ini.WriteString('   ', 'Name3', 'VALUES-3');
  end;
  Ini.WriteString(#9#9, 'Name1', 'VALUETT-1');  {߂ĂȂ}
  Ini.WriteString(#9#9, 'Name2', 'VALUETT-2');
  Ini.WriteString(#9#9, 'Name3', 'VALUETT-3');
  Ini.WriteString(#9' '#9, 'Name1', 'VALUETST-1');
  Ini.WriteString(#9' '#9, 'Name2', 'VALUETST-2');
  Ini.WriteString(#9' '#9, 'Name3', 'VALUETST-3');
  Ini.WriteString(#9#9#9, 'Name1', 'VALUESTTTS-1');
  Ini.WriteString(#9#9#9, 'Name2', 'VALUESTTTS-2');
  Ini.WriteString(#9#9#9, 'Name3', 'VALUESTTTS-3');
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := ResultIniFileSpaceTabSection;
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;

procedure MakeIniFileEmptySection;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add('');
  StrList.Add('[]');
  StrList.Add('Name1=Value[]-1');
  StrList.Add('Name2=Value[]-2');
  StrList.Add('');
  StrList.Add('[');
  StrList.Add('Name1=Value[-1');
  StrList.Add('Name2=Value[-2');
  StrList.Add('');
  StrList.Add(']');
  StrList.Add('Name1=Value[-1');
  StrList.Add('Name2=Value[-2');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=Value1-1');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('');
  StrList.Add('[]');
  StrList.Add('Name1=Value[]-1');
  StrList.Add('Name2=Value[]-2');
  StrList.Add('');
  StrList.Add('[');
  StrList.Add('Name1=Value[-1');
  StrList.Add('Name2=Value[-2');
  StrList.Add('');
  StrList.Add(']');
  StrList.Add('Name1=Value[-1');
  StrList.Add('Name2=Value[-2');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=Value2-1');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[]');
  StrList.Add('Name1=Value[]-1');
  StrList.Add('Name2=Value[]-2');
  StrList.Add('');
  StrList.Add('[');
  StrList.Add('Name1=Value[-1');
  StrList.Add('Name2=Value[-2');
  StrList.Add('');
  StrList.Add(']');
  StrList.Add('Name1=Value[-1');
  StrList.Add('Name2=Value[-2');
  StrList.Add('');
  StrList.SaveToFile(ChangeFileExt(ParamStr(0), '.ini'));
  StrList.Free;
end;

function ResultIniFileEmptySection: String;
var
  StrList: TStringList;
begin
  StrList := TStringList.Create;
  StrList.Add('');
  StrList.Add('[]');
  StrList.Add('Name1=Value[]-1');
  StrList.Add('Name2=Value[]-2');
  StrList.Add('');
  StrList.Add('[');
  StrList.Add('Name1=Value[-1');
  StrList.Add('Name2=Value[-2');
  StrList.Add('');
  StrList.Add(']');
  StrList.Add('Name1=Value[-1');
  StrList.Add('Name2=Value[-2');
  StrList.Add('');
  StrList.Add('[Option1]');
  StrList.Add('Name1=VALUE11');
  StrList.Add('Name2=Value1-2');
  StrList.Add('');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('Name3=VALUE13');
  StrList.Add('');
  StrList.Add('[]');
  StrList.Add('Name1=Value[]-1');
  StrList.Add('Name2=Value[]-2');
  StrList.Add('');
  StrList.Add('[');
  StrList.Add('Name1=Value[-1');
  StrList.Add('Name2=Value[-2');
  StrList.Add('');
  StrList.Add(']');
  StrList.Add('Name1=Value[-1');
  StrList.Add('Name2=Value[-2');
  StrList.Add('');
  StrList.Add('[Option2]');
  StrList.Add('Name1=VALUE21');
  StrList.Add('Name2=Value2-2');
  StrList.Add('');
  StrList.Add('svs=CR[');
  StrList.Add(' svs=CR[Cfg');
  StrList.Add('Name3=VALUE23');
  StrList.Add('svs');
  StrList.Add(' svsCfg');
  StrList.Add(';Rg=CR[');
  StrList.Add(' ;Rg=CR[Cfg');
  StrList.Add(';Rg');
  StrList.Add(' ;RgCfg');
  StrList.Add('');
  StrList.Add('[]');
  StrList.Add('Name1=Value[]-1');
  StrList.Add('Name2=Value[]-2');
  StrList.Add('');
  StrList.Add('[');
  StrList.Add('Name1=Value[-1');
  StrList.Add('Name2=Value[-2');
  StrList.Add('');
  StrList.Add(']');
  StrList.Add('Name1=Value[-1');
  StrList.Add('Name2=Value[-2');
  StrList.Add('');
  StrList.Add('[Option3]');
  StrList.Add('Name1=VALUE31');
  Result := StrList.Text;
  StrList.Free;
end;

procedure testIniFileWriteEmptySection(Ini: TCustomIniFile);
var
  BeforeWriteString: String;
  AfterWriteString: String;
begin
  with UnitTest do begin
  BeforeWriteString := LoadStringFromFile(AppIniFilePath);
  Ini.WriteString('Option1', 'Name1', 'VALUE11');
  Ini.WriteString('Option1', 'Name3', 'VALUE13');
  Ini.WriteString('Option2', 'Name1', 'VALUE21');
  Ini.WriteString('Option3', 'Name1', 'VALUE31');
  Ini.WriteString('Option2', 'Name3', 'VALUE23');
  Ini.UpdateFile;
  Ini.Free;

  BeforeWriteString := ResultIniFileEmptySection;
  AfterWriteString  := LoadStringFromFile(AppIniFilePath);
  Form1.Memo1.Text := BeforeWriteString;
  Form1.Memo2.Text := AfterWriteString;
  Check(BeforeWriteString, AfterWriteString);
  end;
end;

procedure testIniWriteString;
var
  MsgShow: Boolean;

  function MsgBoxShow(Msg: string): Boolean;
  begin
    Result := False;
    if MsgShow then
      if AppMsgBox(Msg, '', MB_YESNO) = IDYES then
      begin
        DoubleMemoCheck;
        Result := True;
      end;
  end;

begin
  MsgShow := False;
  UnitTest.Initialize;
  UnitTest.WriteLog(TIniFile.ClassName);
  MakeIniFileHoldComment1;   testIniFileHoldComment1(TIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment1;   testIniFileHoldComment2(TIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment1;   testIniFileHoldComment3(TIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment2;   testIniFileNewItem2(TIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment3;   testIniFileWriteTrimIdent(TIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment3_1; testIniFileWriteTrimIdent_1(TIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment3_2; testIniFileWriteTrimIdent_2(TIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment3_3; testIniFileWriteTrimIdent_3(TIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment3_4; testIniFileWriteTrimIdent_4(TIniFile.Create(AppIniFilePath));
  {3_1/_2/_3...͍ŌKeyǉ̋ɂăeXgsĂ}
  MakeIniFileHoldComment4;   testIniFileWriteTrimSection(TIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment1;   testIniFileNewItem(TIniFile.Create(AppIniFilePath));
  MakeIniFileSpaceTabSection;testIniFileWriteSpaceTabSection(TIniFile.Create(AppIniFilePath));
  MakeIniFileEmptySection;testIniFileWriteEmptySection(TIniFile.Create(AppIniFilePath));
  UnitTest.AssertSwitch := False;
  MakeIniFileHoldComment1;   testIniFileNoUpdate(TIniFile.Create(AppIniFilePath));
  UnitTest.AssertSwitch := True;
  if MsgBoxShow('~܂'+#13+ UnitTest.Finalize + #10 + TIniFile.ClassName) then
    raise Exception.Create('~܂');

  UnitTest.Initialize;
  UnitTest.WriteLog(TAccessIniFile.ClassName);
  MakeIniFileHoldComment1;   testIniFileHoldComment1(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment1;   testIniFileHoldComment2(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment1;   testIniFileHoldComment3(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment1;   testIniFileNoUpdate(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment2;   testIniFileNewItem2(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment3;   testIniFileWriteTrimIdent(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment3_1; testIniFileWriteTrimIdent_1(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment3_2; testIniFileWriteTrimIdent_2(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment3_3; testIniFileWriteTrimIdent_3(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment3_4; testIniFileWriteTrimIdent_4(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment4;   testIniFileWriteTrimSection(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileHoldComment1;   testIniFileNewItem(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileSpaceTabSection;testIniFileWriteSpaceTabSection(TAccessIniFile.Create(AppIniFilePath));
  MakeIniFileEmptySection;testIniFileWriteEmptySection(TAccessIniFile.Create(AppIniFilePath));
  if MsgBoxShow('~܂'+#13+ UnitTest.Finalize + #10 + TAccessIniFile.ClassName) then
    raise Exception.Create('~܂');


(*-------------------------------
WriteStringn
> ERgsCfg܂߂ĂƎc邱ƂmF
> EsvsCfg܂߂ĂƎc鎖mF
> E_~[Name=ValuesCfg܂߂ĂƎc邱ƂmF
    LRtestIniFileHoldComment1ŊmF

> EValueɑ召ύXlłƃt@CXV邩ǂ
    testIniFileHoldComment2ŊmF

> EValueɑOɃXy[X/^uꂽlŐt@CXV邩ǂ
    testIniFileHoldComment3ŊmF

> EValueɌ̕ƓlāAt@CXV(t)ȂƂmFB
>   TAccessIniFile̓Ǝ@\
    testIniFileNoUpdateŊmF

> ĹAeLXg-Option1-eLXg-Option2-eLXg
>   ̌`ɂ

> E݂Ȃڂ̒ǉ̓ZNV̍ŌName=Value̒
>   Ȃ邱ƂmFB
>   svsARgsȂǂ͖đOT邱
>   ATIniFile̓sōŏIZNV̏ꍇɂ͑OT͂ĂȂB
    testIniFileNewItem2ŊmF

> EZNVڂɉeȂƂmF
>   [Option1]Name1=Value1[]Name2=Value2
>   Option1,Name2͎擾łȂ
>   ZNVƂāw[]xw[xw]xg
	testIniFileWriteEmptySectionŊmF

> EZNV݂݂̂
>   Name=ValueȂꍇ̓ZNVs̒ɒǉ̂mFB
    testIniFileNewItem2Option0ŊmF

> EZNV݂Ȃꍇ͍ŌɃZNV쐬邱ƂmF
    testIniFileNewItem2Option4ŊmF

> EIdent̑OɃXy[X/^ûł߂邩ǂmF
    testIniFileWriteTrimIdentŊmF

> ESection̑OɃXy[X/^ûł߂邩ǂmF
    testIniFileWriteTrimIdentŊmF

> EXy[X/^uIdentŏ߂邩ǂmFB
    testIniFileNewItemŊmF

> EXy[XZNV^uZNVŌł邩ǂmFB
    testIniFileWriteSpaceTabSectionŊmF
//-------------------------------*)
end;

end.
